==> flamerobin_0.8.6.orig.tar.gz: flamerobin-0.8.6-src/src/gui/ExecuteSql.cpp <==
/*
  Copyright (c) 2004-2008 The FlameRobin Development Team

  Permission is hereby granted, free of charge, to any person obtaining
  a copy of this software and associated documentation files (the
  "Software"), to deal in the Software without restriction, including
  without limitation the rights to use, copy, modify, merge, publish,
  distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to
  the following conditions:

  The above copyright notice and this permission notice shall be included
  in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: ExecuteSql.cpp 1631 2008-02-02 22:25:30Z mapopa $

*/
//-----------------------------------------------------------------------------
// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

// for all others, include the necessary headers (this file is usually all you
// need because it includes almost all "standard" wxWindows headers
#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif

#include "gui/ExecuteSql.h"
#include "gui/ExecuteSqlFrame.h"
//-----------------------------------------------------------------------------
ExecuteSqlFrame* showSql(wxWindow* parent, const wxString& title,
    Database *database, const wxString &sql)
{
    ExecuteSqlFrame *eff = new ExecuteSqlFrame(parent, -1, title, database);
    eff->Show();
    eff->setSql(sql);
    return eff;
}
//-----------------------------------------------------------------------------
void execSql(wxWindow* parent, const wxString& title, Database *database,
    const wxString &sql, bool closeWindow)
{
    ExecuteSqlFrame *eff = showSql(parent, title, database, sql);
    eff->Update();
    eff->executeAllStatements(closeWindow);
}
//-----------------------------------------------------------------------------

==> flamerobin_0.9.0.orig.tar.gz: flamerobin-0.9.0-src/src/gui/ExecuteSql.cpp <==
/*
  Copyright (c) 2004-2008 The FlameRobin Development Team

  Permission is hereby granted, free of charge, to any person obtaining
  a copy of this software and associated documentation files (the
  "Software"), to deal in the Software without restriction, including
  without limitation the rights to use, copy, modify, merge, publish,
  distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to
  the following conditions:

  The above copyright notice and this permission notice shall be included
  in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: ExecuteSql.cpp 1729 2008-08-21 09:24:37Z mghie $

*/
//-----------------------------------------------------------------------------
// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

// for all others, include the necessary headers (this file is usually all you
// need because it includes almost all "standard" wxWindows headers
#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif

#include "gui/ExecuteSql.h"
#include "gui/ExecuteSqlFrame.h"
//-----------------------------------------------------------------------------
ExecuteSqlFrame* showSql(wxWindow* parent, const wxString& title,
    Database *database, const wxString &sql)
{
    ExecuteSqlFrame* eff = new ExecuteSqlFrame(parent, -1, title, database);
    eff->Show();
    // bug reported 2008-08-19 by Valdir Marcos: status bar position wrong
    // when ExecuteSqlFrame is created in maximized state
    if (eff->IsMaximized())
        eff->SendSizeEvent();
    eff->setSql(sql);
    return eff;
}
//-----------------------------------------------------------------------------
void execSql(wxWindow* parent, const wxString& title, Database *database,
    const wxString &sql, bool closeWindow)
{
    ExecuteSqlFrame *eff = showSql(parent, title, database, sql);
    eff->Update();
    eff->executeAllStatements(closeWindow);
}
//-----------------------------------------------------------------------------
